
//-------------------------------------------------------------------------
// NeoFox Channel Status
//-------------------------------------------------------------------------
#define NEOFOX_CHAN_CLOSED     0x0000    // Channel is closed
#define NEOFOX_CHAN_INIT       0x0001    // Channel is open, initializing
#define NEOFOX_CHAN_READY      0x0002    // Channel is open, ready for data collection
#define NEOFOX_CHAN_DATA       0x0003    // Channel is open, receiving data, no ID received
#define NEOFOX_CHAN_ACTIVE     0x0004    // Channel is open, collecting data
#define NEOFOX_CHAN_TIMEOUT    0x0005    // Channel is open, no valid data timeout

//-------------------------------------------------------------------------
// NeoFox Selection Information ID's (for use with DeviceGetInfoSelect)
//-------------------------------------------------------------------------
#define NEOFOX_SELECT_INFO_NAME             0  // Name of discovered NeoFox
#define NEOFOX_SELECT_INFO_TYPE             1  // Connection Type Information
#define NEOFOX_SELECT_INFO_ID               2  // Serial Number / ID
#define NEOFOX_SELECT_INFO_DEVICETYPE       3  // Connection Type (USB, IP, Legacy COM)
#define NEOFOX_SELECT_INFO_NUMCHANNELS      4  // Number Of Channels In This Device
#define NEOFOX_SELECT_INFO_DEVICENUM        5  // USB Device Number

//-------------------------------------------------------------------------
// NeoFox Data Types
//-------------------------------------------------------------------------
// Raw Sensor Types
#define DTYPE_APD_SENSOR             0      // APD Sensor Data
#define DTYPE_LED_TIMING             1      // LED Cycle Timing

// Trending Types 
#define DTYPE_RAW_PHASE              2      // Raw Phase Measurement
#define DTYPE_SENSOR_TEMPERATURE     3      // Sensor Temperature
#define DTYPE_BOARD_TEMPERATURE1     4      // Board Temperature 1
#define DTYPE_BOARD_TEMPERATURE2     5      // Board Temperature 2
#define DTYPE_BOARD_TEMPERATURE3     6      // Board Temperature 3

#define DTYPE_PHASE                  7      // Phase Measurement
#define DTYPE_DECAY_TIME             8      // Decay Time
#define DTYPE_TAU                    9      // Tau
#define DTYPE_OXYGEN                 10     // Oxygen

/*------------------------------------------------------------------------*/
/*                                                                        */
/*   Exports For DLL Access                                               */
/*                                                                        */
/*------------------------------------------------------------------------*/
// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the NEOFOX_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// NEOFOX_API functions as being imported from a DLL, wheras this DLL sees symbols
// defined with this macro as being exported.
#ifdef NEOFOX_EXPORTS
#define NEOFOX_API __declspec(dllexport) int _stdcall 
#define NEOFOX_API_FLOAT __declspec(dllexport) float _stdcall 
#else
#define NEOFOX_API __declspec(dllimport) int _stdcall 
#define NEOFOX_API_FLOAT __declspec(dllimport) float _stdcall 
#endif

// Standard Routines
NEOFOX_API ApplicationStartup(int hInstance);
NEOFOX_API DeviceCheckHandle(int hDevice);
NEOFOX_API DeviceGetParameter(int hDevice, int ParamType, LPTSTR szText);
NEOFOX_API_FLOAT DeviceGetParameterFloat(int hDevice, int ParamType, LPTSTR szText);
NEOFOX_API DeviceSetParameter(int hDevice, int ParamType, int dValue);
NEOFOX_API DeviceSetParameterFloat(int hDevice, int ParamType, float dValue);
NEOFOX_API DeviceSetParameterString(int hDevice, int ParamType, LPTSTR szText);
NEOFOX_API DeviceGetCurrentDataPtr(int hDevice);
NEOFOX_API DeviceClose(int hDevice);
NEOFOX_API ApplicationShutdown();

// Device LCD Graphics Routines
NEOFOX_API DeviceGraphicsText(int hDevice, int FontType, int TextFlags, int PosX, int PosY, char *szText);
NEOFOX_API DeviceGraphicsClear(int hDevice, int PosX, int PosY, int SizeX, int SizeY);
NEOFOX_API DeviceGraphicsBitmap(int hDevice, int BmpPosX, int BmpPosY, int BmpSizeX, int BmpSizeY, int DstPosX, int DstPosY, int DstSizeX, int DstSizeY, int Invert, unsigned char *bmpData, int BytesPerLine);

// Target Specific Routines
NEOFOX_API DeviceGetInfoSelect(int Select, int InfoType, LPTSTR szString);
NEOFOX_API DeviceOpenChannel(int Select, int SubChannel, int ShowGUI);
NEOFOX_API DevicePerformDiscovery(int vendorID, int productID, int ShowGUI);

NEOFOX_API DeviceUSBInitialize(struct TDeviceInfo *DeviceInfo, int SubChannel, int ShowGUI);
NEOFOX_API DeviceGetStatus(int hDeviceHandle);

NEOFOX_API DeviceCheckForNewData(int hDeviceHandle);
NEOFOX_API DeviceGetSensorData(int hDevice, unsigned int *arrayPtr, int NumWaveforms, int NumSamples);

// NeoFox GUI / Algorithms Implementation
NEOFOX_API DeviceReset(int hDeviceHandle);
NEOFOX_API DeviceDecodeStream(int hDeviceHandle, BYTE *rcvBuffer, int rcvCnt);

// Download
NEOFOX_API DeviceSendFirmwareData(int hDevice, int FirmwareSizeBytes, int TotalFrames, int CurrentFrame, int CurrentFrameSize, unsigned char *arrayPtr);
